#!/bin/ksh
#
##############################################################################
# lmutil version 10.1 Workstation
# script to run lmutil (or other FLEXlm utilities, e.g., lmstat, lmdown, etc.)
##############################################################################
#
#####################################################
#####            Copyright 1998-2008            #####
##### Vanderplaats Research & Development, Inc. #####
#####            All rights reserved.           #####
#####################################################
#
##############################################################################
#  Start of user modifiable part -- Set these variables accordingly
##############################################################################
#
# VRAND_PATH should have been set by the installation script
#
# set values for:
#  VRAND_PATH     (the path to the installation directory + /vrand)
#
VRAND_PATH="ZZZvrand_pathZZZ"
#
##############################################################################
#  End of user modifiable part -- NOTHING BELOW THIS LINE SHOULD BE CHANGED!
##############################################################################
#
if [ ! -d "$VRAND_PATH" ]; then
   what=`basename "$0"`
   where=`dirname "$0"`
   here=`pwd`
   test x"$where" = x. && where="$here"
   case $where in
      /*) : ;;
      *) where="$here/$where" ;;
   esac
   while [ -L "$where/$what" ]; do
      ls=`/bin/ls -l "$where/$what"`
      cmd=`expr "$ls" : ".*-> \(.*\)"`
      what=`basename "$cmd"`
      newwhere=`dirname "$cmd"`
      test x"$newwhere" = x. && newwhere="$where"
      case $newwhere in
         /*) : ;;
         *) newwhere="$where/$newwhere" ;;
      esac
      where="$newwhere"
   done
   case $where in
      */vrand/bin) 
         VRAND_PATH=`expr "$where" : "\(.*\)/bin"`
      ;;
      *) printf "Error: not properly installed!
       Edit the lmutil script and set the variable \"VRAND_PATH\"
       to the full path to the vrand directory.
" >&2
         exit 1
      ;;
   esac
fi
#
OSTYPE=`uname`
case $OSTYPE in
   AIX*)  OSTYPE="AIX" ;;
   IRIX*) OSTYPE="IRIX" ;;
   Linux) OSTYPE="Linux_ix86"
      case `uname -m` in
         ia64*) OSTYPE="Linux_ia64" ;;
      esac
   ;;
   HP-UX)
      case `model` in
         ia64*) OSTYPE="HP-UX_ia64" ;;
      esac
   ;;
   Darwin) OSTYPE="Darwin_ix86"
      case `arch` in
         ppc*) OSTYPE="Darwin_ppc" ;;
      esac
   ;;
esac
#
if [ ! -x "$VRAND_PATH/flexlm/$OSTYPE/lmutil" ]; then
   printf "Error: lmutil executable not found!
Check the setting of the \"VRAND_PATH\" variable in the lmutil script.\n" >&2
   exit 1
fi
#
LMPROG=`basename $0`
case $LMPROG in
   lmutil)
      LMPROG="$1"
      test $# -gt 0 && shift
   ;;
esac
licgiven=0
for arg in "$@"; do
   case "$arg" in
      -c) licgiven=1
      ;;
   esac
done
minusc=
licfile= 
case $LMPROG in
   lminstall|lmhostid|lmver)
      :
   ;;
   *)
      if [ x$licgiven != x1 ]; then
         for file in $VRAND_PATH/licenses/*.lic; do
            if [ -f $file ]; then
               if [ x$licfile = x ]; then
                  minusc=-c
                  licfile=$file
               else
                  licfile=$licfile:$file
               fi
            fi
         done
      fi
   ;;
esac
#
exec "$VRAND_PATH/flexlm/$OSTYPE/lmutil" "$LMPROG" $minusc $licfile "$@"
