#!/bin/sh
#
##################################################
# nastran_wrapper version 10.1 Workstation/Server
# example of how to run Nastran so that it uses 
# VRANDSMS External Matrix Eigenvalue Solver
##################################################
#
#
#   There are two important steps to setting up a job that uses SMS.
#
#   1.  EDIT the Nastran input file.
#
#       Add two lines as follows:
#       Add "INCLUDE 'MSC_ISHELLPATH:sms_assign_V2005'" as the very first line.
#       Add "INCLUDE 'MSC_ISHELLPATH:sms_dmap_V2005'" right before the CEND line.
#
#       Make sure the EIGRL entry in the Nastran input file has
#       a non-blank upper bound cut-off frequency (this is optional in
#       Nastran, but is REQUIRED by SMS).
#
#   2.  Set some environment variables that SMS needs.  At a minimum, you
#       must set three variables:  VRAND_PATH, MSC_ISHELLPATH, and SMS_MEM
#       VRAND_PATH="ZZZvrand_pathZZZ"
#       MSC_ISHELLPATH="$VRAND_PATH/sms"
#       SMS_MEM=400Mb (replace the amount with how much you want) 
#
#       export VRAND_PATH
#       export MSC_ISHELLPATH
#       export SMS_MEM
#
#       You can OPTIONALLY set some parameters that affect SMS's performance.
#       The environment variables SMS_PARAM1, SMS_PARAM2, and SMS_PARAM3
#       control the trade-off between speed and accuracy.  In general,
#       higher numbers mean more accuracy, but makes SMS work longer.
#       Lower numbers mean less accuracy, but SMS finishes faster.  There
#       are some rules for these parameters:
#           SMS_PARAM1 must be greater than SMS_PARAM2
#           SMS_PARAM2 must be greater than SMS_PARAM3
#           SMS_PARAM3 must be greater than 1.0
#       You should only set these variables if you want to make SMS work
#       faster (and are willing to accept results that are less accurate).
#
#   Once you have completed the above two steps, then run Nastran as
#   you normally would.  The VRAND/SMS solver will be used instead of
#   Nastran's Lanczos method.  The Nastran output file and any
#   post-processing files will look just as they normally would.
#
#   Note:
#      This file can be used as a script run nastran jobs that use SMS.
#
#      ***  YOU MUST EDIT THIS FILE TO USE IT TO RUN NASTRAN JOBS  ***
#
#      Search below for the key "+++ EDIT HERE +++" to see what you need
#      to change
#
# Example Nastran input file:
#
#   $----------------------------------------------------------------
#   $---- Added Include 1 -------------------------------------------
#   INCLUDE 'MSC_ISHELLPATH:sms_assign_V2005'
#   $----------------------------------------------------------------
#   TIME 1
#   SOL 103
#   DIAG 8,15
#   $----------------------------------------------------------------
#   $---- Added Include 2 -------------------------------------------
#   INCLUDE 'MSC_ISHELLPATH:sms_dmap_V2005'
#   $----------------------------------------------------------------
#   CEND  
#   $
#   TITLE = DEMO TEST 
#   SUBTITLE = SOL103 with VRANDSMS
#   ECHO = NONE
#   SET 101 = 250001, 25092, 25090
#   METHOD=2
#   SUBCASE 1
#     MODES=10
#     DISP(PUNCH)=101 
#   SUBCASE 11
#     DISP(PUNCH)=NONE
#   BEGIN BULK
#   EIGRL,2,-1.,800.0,14
#   INCLUDE 'demo.bulk'
#   ENDDATA
#
##############################################################################
#  Start of user modifiable part -- Set these variables accordingly
##############################################################################
#
# If you are using NQS (or a similar batch system), put your parameters here
# +++ EDIT HERE +++ (optional)
# QSUB -r demo
# QSUB -eo 
# QSUB -s /bin/sh
# QSUB -lT 600 
# QSUB -lM 112MW  
#
#  VRAND_PATH should be the  path to the
#             VRANDSMS installation directory + /vrand
#
VRAND_PATH="ZZZvrand_pathZZZ"
#
# set the path to the nastran
#
# +++ EDIT HERE +++
nast_cmd=/usr/local/msc/bin/nastran
#
# set memory for nastran and sms
#
# +++ EDIT HERE +++
nast_mem=2Mw
# +++ EDIT HERE +++
SMS_MEM=4Mw
#
# set the nastran directories for the run
#
# +++ EDIT HERE +++
run_dir=/home/user1/model1
# +++ EDIT HERE +++
scratch=/bigdisk/user1/model1
#
# set the file name 
#
# +++ EDIT HERE +++
dat_file=model1_sms.dat
#
#  SMS time/accuracy trade-off parameters
#
#      SMS_PARAM1 must be greater than SMS_PARAM2
#      SMS_PARAM2 must be greater than SMS_PARAM3
#      SMS_PARAM3 must be greater than 1.0
#
#      Higher numbers will generally take more time, but result in more
#      accurate results.
#
#  Optionally set the SMS time/accuracy trade-off parameters here
#  (Leave commented out to accept the default parameters)
#
# +++ EDIT HERE +++ (optional)
#SMS_PARAM1=7.0
#export SMS_PARAM1
#SMS_PARAM2=2.0
#export SMS_PARAM2
#SMS_PARAM3=1.4
#export SMS_PARAM3
#
##############################################################################
#  End of user modifiable part -- NOTHING BELOW THIS LINE SHOULD BE CHANGED!
##############################################################################
#
export SMS_MEM
export VRAND_PATH
#
MSC_ISHELLPATH="$VRAND_PATH/sms"
export MSC_ISHELLPATH
#
cd $run_dir
$nast_cmd $dat_file bat=no mem=$nast_mem old=no scratch=yes sdir=$scratch
#

